
/* Chrysalide - Outil d'analyse de fichiers binaires
 * editem.h - prototypes pour la gestion des différents éléments réactifs de l'éditeurs
 *
 * Copyright (C) 2010-2013 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  OpenIDA is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  OpenIDA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef _GUI_EDITEM_H
#define _GUI_EDITEM_H


#include <glib-object.h>


#include "../analysis/binary.h"
#include "../analysis/project.h"
#include "../gtkext/gtkviewpanel.h"



/* ------------------------- ELEMENT INDIVIDUEL D'INTERFACE ------------------------- */


#define G_TYPE_EDITOR_ITEM               g_editor_item_get_type()
#define G_EDITOR_ITEM(obj)               (G_TYPE_CHECK_INSTANCE_CAST((obj), g_editor_item_get_type(), GEditorItem))
#define G_IS_EDITOR_ITEM(obj)            (G_TYPE_CHECK_INSTANCE_TYPE((obj), g_editor_item_get_type()))
#define G_EDITOR_ITEM_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST((klass), G_TYPE_EDITOR_ITEM, GEditorItemClass))
#define G_IS_EDITOR_ITEM_CLASS(klass)    (G_TYPE_CHECK_CLASS_TYPE((klass), G_TYPE_EDITOR_ITEM))
#define G_EDITOR_ITEM_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_EDITOR_ITEM, GEditorItemClass))


/* Elément réactif quelconque de l'éditeur (instance) */
typedef struct _GEditorItem GEditorItem;

/* Elément réactif quelconque de l'éditeur (classe) */
typedef struct _GEditorItemClass GEditorItemClass;


/* Indique le type défini pour un élément réactif d'éditeur. */
GType g_editor_item_get_type(void);

/* Fournit l'adresse de l'espace de référencement global. */
GObject *g_editor_item_get_global_ref(const GEditorItem *);

/* Fournit le nom humain attribué à l'élément réactif. */
const char *g_editor_item_get_name(const GEditorItem *);

/* Fournit le composant GTK associé à l'élément réactif. */
GtkWidget *g_editor_item_get_widget(const GEditorItem *);

/* Fournit le gestionnaire du binaire courant. */
GLoadedBinary *g_editor_item_get_current_binary(const GEditorItem *);

/* Fournit l'affichage de binaire courant. */
GtkViewPanel *g_editor_item_get_current_view(const GEditorItem *);



/* ---------------------------- MANIPULATION D'ENSEMBLES ---------------------------- */


/* Procède à l'enregistrement d'un élément reactif de l'éditeur. */
void register_editor_item(GEditorItem *);

/* Lance une actualisation du fait d'un changement de binaire. */
void change_editor_items_current_binary(GObject *, GLoadedBinary *);

/* Lance une actualisation du fait d'un changement de vue. */
void change_editor_items_current_view(GObject *, GtkViewPanel *);

/* Lance une actualisation du fait d'un changement de contenu. */
void change_editor_items_current_view_content(GtkViewPanel *);

/* Concentre l'attention de l'ensemble sur une adresse donnée. */
void focus_address_in_editor_items(GLoadedBinary *, const vmpa2t *, GEditorItem *);

/* Lance une actualisation relative à l'étendue du projet. */
void update_project_area(GStudyProject *);



#endif  /* _GUI_EDITEM_H */
